Random Variables
==================================

This module provides variable representations for concept-based probabilistic models.

.. currentmodule:: torch_concepts

Summary
-------

**Variable Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   Variable
   EndogenousVariable
   ExogenousVariable
   InputVariable


Class Documentation
-------------------

.. autoclass:: Variable
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: EndogenousVariable
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ExogenousVariable
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: InputVariable
   :members:
   :undoc-members:
   :show-inheritance:

